
From: Denis Vlasenko <vda@ilport.com.ua>

- Increase error message verbosity with respect to monitor timings.

- Fix default sync timings

Signed-off-by: Antonino Daplas <adaplas@pol.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/video/i810/i810_main.c |   12 +++++++++---
 1 files changed, 9 insertions(+), 3 deletions(-)

diff -puN drivers/video/i810/i810_main.c~i810fb-fix-default-monitor-sync-timings drivers/video/i810/i810_main.c
--- 25/drivers/video/i810/i810_main.c~i810fb-fix-default-monitor-sync-timings	2005-04-25 19:23:25.056199656 -0700
+++ 25-akpm/drivers/video/i810/i810_main.c	2005-04-25 19:23:25.166182936 -0700
@@ -999,8 +999,14 @@ static int i810_check_params(struct fb_v
 	info->monspecs.dclkmin = 15000000;
 
 	if (fb_validate_mode(var, info)) {
-		if (fb_get_mode(FB_MAXTIMINGS, 0, var, info))
+		if (fb_get_mode(FB_MAXTIMINGS, 0, var, info)) {
+			int default_sync = (hsync1-HFMIN)|(hsync2-HFMAX)
+					    |(vsync1-VFMIN)|(vsync2-VFMAX);
+			printk("i810fb: invalid video mode%s\n",
+			    default_sync ? "" :
+			    ". Specifying vsyncN/hsyncN parameters may help");
 			return -EINVAL;
+		}
 	}
 	
 	var->xres = xres;
@@ -2023,10 +2029,10 @@ MODULE_PARM_DESC(vyres, "Virtual vertica
 		 " (default = 480)");
 module_param(hsync1, int, 0);
 MODULE_PARM_DESC(hsync1, "Minimum horizontal frequency of monitor in KHz"
-		 " (default = 31)");
+		 " (default = 29)");
 module_param(hsync2, int, 0);
 MODULE_PARM_DESC(hsync2, "Maximum horizontal frequency of monitor in KHz"
-		 " (default = 31)");
+		 " (default = 30)");
 module_param(vsync1, int, 0);
 MODULE_PARM_DESC(vsync1, "Minimum vertical frequency of monitor in Hz"
 		 " (default = 50)");
_
